:orphan:

.. _general_examples:

Examples
========

General examples
----------------

General-purpose and introductory examples for joblib.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Randomness is affected by parallel execution differently by the different backends.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_parallel_random_state_thumb.png

        :ref:`sphx_glr_auto_examples_parallel_random_state.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/parallel_random_state

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates how to cache intermediate computing results using :class:`joblib.Memor...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_nested_parallel_memory_thumb.png

        :ref:`sphx_glr_auto_examples_nested_parallel_memory.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/nested_parallel_memory

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates the usage of :class:`joblib.Memory` with both functions and methods.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_memory_basic_usage_thumb.png

        :ref:`sphx_glr_auto_examples_memory_basic_usage.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/memory_basic_usage

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates some features enabled by using a memory map (:class:`numpy.memmap`) wi...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_parallel_memmap_thumb.png

        :ref:`sphx_glr_auto_examples_parallel_memmap.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/parallel_memmap

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example compares the compressors available in Joblib. In the example, Zlib, LZMA and LZ4 c...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_compressors_comparison_thumb.png

        :ref:`sphx_glr_auto_examples_compressors_comparison.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/compressors_comparison
.. raw:: html

    <div style='clear:both'></div>

.. _parallel_examples:

Parallel examples
-----------------

Examples demoing more advanced parallel patterns.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows the simplest usage of the dask `distributed &lt;https://distributed.readthedocs...">

.. only:: html

    .. figure:: /auto_examples/parallel/images/thumb/sphx_glr_distributed_backend_simple_thumb.png

        :ref:`sphx_glr_auto_examples_parallel_distributed_backend_simple.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/parallel/distributed_backend_simple
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/ogrisel/code/joblib/doc/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/ogrisel/code/joblib/doc/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
